# name: screensaver in X11
# desc: wrapper manifest for xscreensaver
# auth: Kai Burghardt <kburgha at gwdg.de>
#  vim: set tw=140 ts=4 noet bs=eol,start,indent:

# this sub-module sets up a screensaver for the X window system

# in this example, all programs are inactive

class screensaver::x {
	$_text_url                     = $facts['os']['distro']['id'] ? {
		'Debian'                      => 'http://planet.debian.org/rss20.xml',
		'Ubuntu'                      => 'http://fridge.ubuntu.com/node/feed',
		default                       => '',
	}
	$_manual_command               = @(EOT)
			yelp man:%s || \
			x-terminal-emulator -title '%s manual' \
			-e /bin/sh -c 'man "%s"'
			|-EOT
	$_new_login_command            = $facts['os']['distro']['id'] ? {
		'Debian'                      => 'gdmflexiserver -ls',
		'Ubuntu'                      => 'dm-tool switch-to-greeter',
		default                       => '',
	}
	
	class { 'xscreensaver':
		manage_xscreensaver_defaults  => true,
		# xdg-autostart
		manage_xdg_autostart          => true,
		xdg_autostart_file_type       => 'regularfile',
		manage_wrapper_script         => true,
		# app-defaults
		splash                        => true,
		splash_heading_label          => 'XScreenSaver %s',
		splash_body_label             => 'copyright \251 1991-2014 by',
		splash_body2_label            => 'Jamie Zawinski <jwz@jwz.org>',
		splash_demo_label             => 'settings',
		demo_command                  => '/usr/bin/xscreensaver-demo',
		prefs_command                 => '/usr/bin/xscreensaver-demo -prefs',
		splash_help_label             => 'help',
		splash_duration               => {hours => 0, minutes =>  0, seconds => 4},
		timeout                       => {hours => 0, minutes => 16, seconds => 0},
		pointer_poll_time             => {hours => 0, minutes =>  0, seconds => 8},
		pointer_hysteresis            => 10,
		sgi_saver_extension           => true,
		xidle_extension               => true,
		proc_interrupts               => true,
		xinput_extension_dev          => false,
		fade                          => true,
		fade_seconds                  => 4,
		fade_ticks                    => 16,
		mode                          => 'blank',
		visual_id                     => 'default',
		cycle                         => {hours => 0, minutes => 16, seconds =>  0},
		ignore_uninstalled_programs   => true,
		get_view_port_is_full_of_lies => false,
		install_colormap              => true,
		text_mode                     => 'literal',
		text_literal                  => 'XScreenSaver',
		text_file                     => '',
		text_program                  => 'fortune',
		text_url                      => $_text_url,
		grab_desktop_images           => false,
		grab_video_frames             => false,
		choose_random_images          => false,
		image_directory               => '',
		nice                          => 16,
		memory_limit                  => 0,
		dpms_enabled                  => false,
		dpms_quickoff_enabled         => false,
		dpms_standby                  => {hours => 0, minutes => 32, seconds => 0},
		dpms_suspend                  => {hours => 0, minutes => 48, seconds => 0},
		dpms_off                      => {hours => 1, minutes =>  0, seconds => 0},
		lock                          => true,
		lock_timeout                  => {hours => 0, minutes =>  0, seconds => 16},
		unfade                        => false,
		passwd_heading_label          => 'XScreenSaver %s',
		passwd_body_label             => 'enter your palabra',
		passwd_uname                  => true,
		passwd_user_label             => 'username:',
		passwd_passwd_label           => 'palabra:',
		passwd_thermometer_background => [0x00, 0x00, 0x00],
		passwd_thermometer_foreground => [0x8A, 0x2B, 0xE2],
		passwd_thermometer_width      => 16,
		passwd_timeout                => {hours => 0, minutes => 0, seconds => 32},
		passwd_passwd_font            => '*-courier-medium-r-*-*-*-140-*-*-*-iso8859-1',
		passwd_asterisks              => true,
		passwd_unlock_label           => 'check!',
		passwd_login_label            => 'switch user',
		new_login_command             => $_new_login_command,
		auth_warning_slack            => 24,
		help_url                      => 'http://www.jwz.org/xscreensaver/man.html',
		load_url                      => 'x-www-browser \'%s\'',
		manual_command                => $_manual_command,
		hacks_doc_is_installed        => true,
		verbose                       => false,
		timestamp                     => true,
		dialog_background             => [0x19, 0x19, 0x70],
		dialog_foreground             => [0xFF, 0xFF, 0xFF],
		dialog_internal_border_width  => 0,
		dialog_border_width           => 0,
		dialog_shadow_thickness       => 4,
		dialog_top_shadow_color       => [0x8A, 0x2B, 0xE2],
		dialog_bottom_shadow_color    => [0x00, 0x00, 0x8B],
		dialog_logo_width             => 256,
		dialog_logo_height            => 256,
		dialog_text_background        => [0x4B, 0x00, 0x82],
		dialog_text_foreground        => [0xFF, 0xFF, 0xFF],
		dialog_body_font              => '*-helvetica-bold-r-*-*-*-140-*-*-*-iso8859-1',
		dialog_heading_font           => '*-helvetica-bold-r-*-*-*-180-*-*-*-iso8859-1',
		dialog_label_font             => '*-helvetica-bold-r-*-*-*-140-*-*-*-iso8859-1',
		dialog_uname_font             => '*-helvetica-bold-r-*-*-*-120-*-*-*-iso8859-1',
		dialog_date_font              => '*-helvetica-medium-r-*-*-*-80-*-*-*-iso8859-1',
		dialog_button_font            => '*-helvetica-bold-r-*-*-*-140-*-*-*-iso8859-1',
		dialog_button_background      => [0x00, 0x00, 0xCD],
		dialog_button_foreground      => [0xFF, 0xFF, 0xFF],
		capture_stderr                => true,
		overlay_stderr                => true,
		font                          => '*-medium-r-*-140-*-m-*',
		overlay_text_background       => [0x00, 0x00, 0x00],
		overlay_text_foreground       => [0xFF, 0xFF, 0x00],
		date_format                   => '%Y-%m-%d %H:%M:%S %Z',
		initial_delay                 => {hours => 0, minutes => 0, seconds => 0},
		window_creation_timeout       => {hours => 0, minutes => 0, seconds => 30},
		bourne_shell                  => '/bin/sh',
		programs                      => {
				'maze -root'                  => {inactive => true},
				'superquadrics -root'         => {inactive => true, visuals => 'GL'},
				'attraction -root'            => {inactive => true},
				'blitspin -root'              => {inactive => true},
				'greynetic -root'             => {inactive => true},
				'helix -root'                 => {inactive => true},
				'hopalong -root'              => {inactive => true},
				'imsmap -root'                => {inactive => true},
				'noseguy -root'               => {inactive => true},
				'pyro -root'                  => {inactive => true},
				'qix -root'                   => {inactive => true},
				'rocks -root'                 => {inactive => true},
				'rorschach -root'             => {inactive => true},
				'decayscreen -root'           => {inactive => true},
				'flame -root'                 => {inactive => true},
				'halo -root'                  => {inactive => true},
				'slidescreen -root'           => {inactive => true},
				'pedal -root'                 => {inactive => true},
				'bouboule -root'              => {inactive => true},
				'braid -root'                 => {inactive => true},
				'coral -root'                 => {inactive => true},
				'deco -root'                  => {inactive => true},
				'drift -root'                 => {inactive => true},
				'fadeplot -root'              => {inactive => true},
				'galaxy -root'                => {inactive => true},
				'goop -root'                  => {inactive => true},
				'grav -root'                  => {inactive => true},
				'ifs -root'                   => {inactive => true},
				'unicode -root'               => {inactive => true},
				'jigsaw -root'                => {inactive => true, visuals => 'GL'},
				'julia -root'                 => {inactive => true},
				'kaleidescope -root'          => {inactive => true},
				'moebius -root'               => {inactive => true, visuals => 'GL'},
				'moire -root'                 => {inactive => true},
				'morph3d -root'               => {inactive => true, visuals => 'GL'},
				'mountain -root'              => {inactive => true},
				'munch -root'                 => {inactive => true},
				'penrose -root'               => {inactive => true},
				'pipes -root'                 => {inactive => true, visuals => 'GL'},
				'rd-bomb -root'               => {inactive => true},
				'rubik -root'                 => {inactive => true, visuals => 'GL'},
				'sierpinski -root'            => {inactive => true},
				'slip -root'                  => {inactive => true},
				'sproingies -root'            => {inactive => true, visuals => 'GL'},
				'starfish -root'              => {inactive => true},
				'strange -root'               => {inactive => true},
				'swirl -root'                 => {inactive => true},
				'triangle -root'              => {inactive => true},
				'xjack -root'                 => {inactive => true},
				'xlyap -root'                 => {inactive => true},
				'atlantis -root'              => {inactive => true, visuals => 'GL'},
				'bsod -root'                  => {inactive => true},
				'bubble3d -root'              => {inactive => true, visuals => 'GL'},
				'cage -root'                  => {inactive => true, visuals => 'GL'},
				'crystal -root'               => {inactive => true},
				'cynosure -root'              => {inactive => true},
				'discrete -root'              => {inactive => true},
				'distort -root'               => {inactive => true},
				'epicycle -root'              => {inactive => true},
				'flow -root'                  => {inactive => true},
				'glplanet -root'              => {inactive => true, visuals => 'GL'},
				'interference -root'          => {inactive => true},
				'kumppa -root'                => {inactive => true},
				'lament -root'                => {inactive => true, visuals => 'GL'},
				'moire2 -root'                => {inactive => true},
				'sonar -root'                 => {inactive => true, visuals => 'GL'},
				'stairs -root'                => {inactive => true, visuals => 'GL'},
				'truchet -root'               => {inactive => true},
				'vidwhacker -root'            => {inactive => true},
				'blaster -root'               => {inactive => true},
				'bumps -root'                 => {inactive => true},
				'ccurve -root'                => {inactive => true},
				'compass -root'               => {inactive => true},
				'deluxe -root'                => {inactive => true},
				'demon -root'                 => {inactive => true},
				'extrusion -root'             => {inactive => true, visuals => 'GL'},
				'loop -root'                  => {inactive => true},
				'penetrate -root'             => {inactive => true},
				'petri -root'                 => {inactive => true},
				'phosphor -root'              => {inactive => true},
				'pulsar -root'                => {inactive => true, visuals => 'GL'},
				'ripples -root'               => {inactive => true},
				'shadebobs -root'             => {inactive => true},
				'sierpinski3d -root'          => {inactive => true, visuals => 'GL'},
				'spotlight -root'             => {inactive => true},
				'squiral -root'               => {inactive => true},
				'wander -root'                => {inactive => true},
				'webcollage -root'            => {inactive => true},
				'xflame -root'                => {inactive => true},
				'xmatrix -root'               => {inactive => true},
				'gflux -root'                 => {inactive => true, visuals => 'GL'},
				'nerverot -root'              => {inactive => true},
				'xrayswarm -root'             => {inactive => true},
				'xspirograph -root'           => {inactive => true},
				'circuit -root'               => {inactive => true, visuals => 'GL'},
				'dangerball -root'            => {inactive => true, visuals => 'GL'},
				'engine -root'                => {inactive => true, visuals => 'GL'},
				'flipscreen3d -root'          => {inactive => true, visuals => 'GL'},
				'gltext -root'                => {inactive => true, visuals => 'GL'},
				'menger -root'                => {inactive => true, visuals => 'GL'},
				'molecule -root'              => {inactive => true, visuals => 'GL'},
				'rotzoomer -root'             => {inactive => true},
				'speedmine -root'             => {inactive => true},
				'starwars -root'              => {inactive => true, visuals => 'GL'},
				'stonerview -root'            => {inactive => true, visuals => 'GL'},
				'vermiculate -root'           => {inactive => true},
				'whirlwindwarp -root'         => {inactive => true},
				'zoom -root'                  => {inactive => true},
				'anemone -root'               => {inactive => true},
				'apollonian -root'            => {inactive => true},
				'boxed -root'                 => {inactive => true, visuals => 'GL'},
				'cubenetic -root'             => {inactive => true, visuals => 'GL'},
				'endgame -root'               => {inactive => true, visuals => 'GL'},
				'euler2d -root'               => {inactive => true},
				'fluidballs -root'            => {inactive => true},
				'flurry -root'                => {inactive => true, visuals => 'GL'},
				'glblur -root'                => {inactive => true, visuals => 'GL'},
				'glsnake -root'               => {inactive => true, visuals => 'GL'},
				'halftone -root'              => {inactive => true},
				'juggler3d -root'             => {inactive => true, visuals => 'GL'},
				'lavalite -root'              => {inactive => true, visuals => 'GL'},
				'polyominoes -root'           => {inactive => true},
				'queens -root'                => {inactive => true, visuals => 'GL'},
				'sballs -root'                => {inactive => true, visuals => 'GL'},
				'spheremonics -root'          => {inactive => true, visuals => 'GL'},
				'thornbird -root'             => {inactive => true},
				'twang -root'                 => {inactive => true},
				'antspotlight -root'          => {inactive => true, visuals => 'GL'},
				'apple2 -root'                => {inactive => true},
				'atunnel -root'               => {inactive => true, visuals => 'GL'},
				'barcode -root'               => {inactive => true},
				'blinkbox -root'              => {inactive => true, visuals => 'GL'},
				'blocktube -root'             => {inactive => true, visuals => 'GL'},
				'bouncingcow -root'           => {inactive => true, visuals => 'GL'},
				'cloudlife -root'             => {inactive => true},
				'cubestorm -root'             => {inactive => true, visuals => 'GL'},
				'eruption -root'              => {inactive => true},
				'flipflop -root'              => {inactive => true, visuals => 'GL'},
				'flyingtoasters -root'        => {inactive => true, visuals => 'GL'},
				'fontglide -root'             => {inactive => true},
				'gleidescope -root'           => {inactive => true, visuals => 'GL'},
				'glknots -root'               => {inactive => true, visuals => 'GL'},
				'glmatrix -root'              => {inactive => true, visuals => 'GL'},
				'glslideshow -root'           => {inactive => true, visuals => 'GL'},
				'hypertorus -root'            => {inactive => true, visuals => 'GL'},
				'jigglypuff -root'            => {inactive => true, visuals => 'GL'},
				'metaballs -root'             => {inactive => true},
				'mirrorblob -root'            => {inactive => true, visuals => 'GL'},
				'piecewise -root'             => {inactive => true},
				'polytopes -root'             => {inactive => true, visuals => 'GL'},
				'pong -root'                  => {inactive => true},
				'popsquares -root'            => {inactive => true},
				'surfaces -root'              => {inactive => true, visuals => 'GL'},
				'xanalogtv -root'             => {inactive => true},
				'abstractile -root'           => {inactive => true},
				'anemotaxis -root'            => {inactive => true},
				'antinspect -root'            => {inactive => true, visuals => 'GL'},
				'fireworkx -root'             => {inactive => true},
				'fuzzyflakes -root'           => {inactive => true},
				'interaggregate -root'        => {inactive => true},
				'intermomentary -root'        => {inactive => true},
				'memscroller -root'           => {inactive => true},
				'noof -root'                  => {inactive => true, visuals => 'GL'},
				'pacman -root'                => {inactive => true},
				'pinion -root'                => {inactive => true, visuals => 'GL'},
				'polyhedra -root'             => {inactive => true, visuals => 'GL'},
				'providence -root'            => {inactive => true, visuals => 'GL'},
				'substrate -root'             => {inactive => true},
				'wormhole -root'              => {inactive => true},
				'antmaze -root'               => {inactive => true, visuals => 'GL'},
				'boing -root'                 => {inactive => true, visuals => 'GL'},
				'boxfit -root'                => {inactive => true},
				'carousel -root'              => {inactive => true, visuals => 'GL'},
				'celtic -root'                => {inactive => true},
				'crackberg -root'             => {inactive => true, visuals => 'GL'},
				'cube21 -root'                => {inactive => true, visuals => 'GL'},
				'fiberlamp -root'             => {inactive => true},
				'fliptext -root'              => {inactive => true, visuals => 'GL'},
				'glhanoi -root'               => {inactive => true, visuals => 'GL'},
				'tangram -root'               => {inactive => true, visuals => 'GL'},
				'timetunnel -root'            => {inactive => true, visuals => 'GL'},
				'glschool -root'              => {inactive => true, visuals => 'GL'},
				'topblock -root'              => {inactive => true, visuals => 'GL'},
				'cubicgrid -root'             => {inactive => true, visuals => 'GL'},
				'cwaves -root'                => {inactive => true},
				'gears -root'                 => {inactive => true, visuals => 'GL'},
				'glcells -root'               => {inactive => true, visuals => 'GL'},
				'lockward -root'              => {inactive => true, visuals => 'GL'},
				'm6502 -root'                 => {inactive => true},
				'moebiusgears -root'          => {inactive => true, visuals => 'GL'},
				'voronoi -root'               => {inactive => true, visuals => 'GL'},
				'hypnowheel -root'            => {inactive => true, visuals => 'GL'},
				'klein -root'                 => {inactive => true, visuals => 'GL'},
				'lcdscrub -root'              => {inactive => true},
				'photopile -root'             => {inactive => true, visuals => 'GL'},
				'skytentacles -root'          => {inactive => true, visuals => 'GL'},
				'rubikblocks -root'           => {inactive => true, visuals => 'GL'},
				'companioncube -root'         => {inactive => true, visuals => 'GL'},
				'hilbert -root'               => {inactive => true, visuals => 'GL'},
				'tronbit -root'               => {inactive => true, visuals => 'GL'},
				'geodesic -root'              => {inactive => true, visuals => 'GL'},
				'hexadrop -root'              => {inactive => true},
				'kaleidocycle -root'          => {inactive => true, visuals => 'GL'},
				'quasicrystal -root'          => {inactive => true, visuals => 'GL'},
				'unknownpleasures -root'      => {inactive => true, visuals => 'GL'},
				'binaryring -root'            => {inactive => true},
				'cityflow -root'              => {inactive => true, visuals => 'GL'},
				'geodesicgears -root'         => {inactive => true, visuals => 'GL'},
				'projectiveplane -root'       => {inactive => true, visuals => 'GL'},
				'romanboy -root'              => {inactive => true, visuals => 'GL'},
				'tessellimage -root'          => {inactive => true},
				'winduprobot -root'           => {inactive => true, visuals => 'GL'},
				'splitflap -root'             => {inactive => true, visuals => 'GL'},
				'testx11 -root'               => {inactive => true},
			},
		hacks__name                   => {
				'antinspect'                  => 'AntInspect',
				'antmaze'                     => 'AntMaze',
				'antspotlight'                => 'AntSpotlight',
				'binaryring'                  => 'BinaryRing',
				'blinkbox'                    => 'BlinkBox',
				'blitspin'                    => 'BlitSpin',
				'blocktube'                   => 'BlockTube',
				'bouncingcow'                 => 'BouncingCow',
				'boxfit'                      => 'BoxFit',
				'bsod'                        => 'BSOD',
				'bubble3d'                    => 'Bubble3D',
				'ccurve'                      => 'CCurve',
				'cloudlife'                   => 'CloudLife',
				'companioncube'               => 'CompanionCube',
				'cubestorm'                   => 'CubeStorm',
				'cubicgrid'                   => 'CubicGrid',
				'cwaves'                      => 'CWaves',
				'dangerball'                  => 'DangerBall',
				'decayscreen'                 => 'DecayScreen',
				'dnalogo'                     => 'DNA Logo',
				'euler2d'                     => 'Euler2D',
				'fadeplot'                    => 'FadePlot',
				'flipflop'                    => 'FlipFlop',
				'flipscreen3d'                => 'FlipScreen3D',
				'fliptext'                    => 'FlipText',
				'fluidballs'                  => 'FluidBalls',
				'flyingtoasters'              => 'FlyingToasters',
				'fontglide'                   => 'FontGlide',
				'fuzzyflakes'                 => 'FuzzyFlakes',
				'geodesicgears'               => 'GeodesicGears',
				'gflux'                       => 'GFlux',
				'gleidescope'                 => 'Gleidescope',
				'glforestfire'                => 'GLForestFire',
				'hyperball'                   => 'HyperBall',
				'hypercube'                   => 'HyperCube',
				'ifs'                         => 'IFS',
				'imsmap'                      => 'IMSMap',
				'jigglypuff'                  => 'JigglyPuff',
				'juggler3d'                   => 'Juggler3D',
				'lcdscrub'                    => 'LCDscrub',
				'lmorph'                      => 'LMorph',
				'm6502'                       => 'm6502',
				'memscroller'                 => 'MemScroller',
				'metaballs'                   => 'MetaBalls',
				'mirrorblob'                  => 'MirrorBlob',
				'moebiusgears'                => 'MoebiusGears',
				'morph3d'                     => 'Morph3D',
				'nerverot'                    => 'NerveRot',
				'noseguy'                     => 'NoseGuy',
				'popsquares'                  => 'PopSquares',
				'projectiveplane'             => 'ProjectivePlane',
				'quasicrystal'                => 'QuasiCrystal',
				'rd-bomb'                     => 'RDbomb',
				'rdbomb'                      => 'RDbomb',
				'romanboy'                    => 'RomanBoy',
				'rotzoomer'                   => 'RotZoomer',
				'rubikblocks'                 => 'RubikBlocks',
				'sballs'                      => 'SBalls',
				'shadebobs'                   => 'ShadeBobs',
				'sierpinski3d'                => 'Sierpinski3D',
				'skytentacles'                => 'SkyTentacles',
				'slidescreen'                 => 'SlideScreen',
				'speedmine'                   => 'SpeedMine',
				'splitflap'                   => 'SplitFlap',
				'starwars'                    => 'StarWars',
				'stonerview'                  => 'StonerView',
				't3d'                         => 'T3D',
				'testx11'                     => 'TestX11',
				'timetunnel'                  => 'TimeTunnel',
				'topblock'                    => 'TopBlock',
				'tronbit'                     => 'TronBit',
				'unknownpleasures'            => 'UnknownPleasures',
				'vidwhacker'                  => 'VidWhacker',
				'webcollage'                  => 'WebCollage',
				'whirlwindwarp'               => 'WhirlWindWarp',
				'winduprobot'                 => 'WindupRobot',
				'xanalogtv'                   => 'XAnalogTV',
				'xrayswarm'                   => 'XRaySwarm',
			},
	}
}
# EOF
