# name: screensaver in X11
# desc: wrapper manifest for xscreensaver
# auth: Kai Burghardt <kburgha at gwdg.de>
#  vim: set tw=140 ts=4 noet bs=eol,start,indent:

# this sub-module sets up a screensaver for the X window system

class screensaver::x11 {
	$_text_url                     = $facts['os']['distro']['id'] ? {
		'Debian'                      => 'http://planet.debian.org/rss20.xml',
		'Ubuntu'                      => 'http://fridge.ubuntu.com/node/feed',
		default                       => '',
	}
	$_manual_command               = @(EOT)
			yelp man:%s || \
			x-terminal-emulator -title '%s manual' \
			-e /bin/sh -c 'man "%s"'
			|-EOT
	$_new_login_command            = $facts['os']['distro']['id'] ? {
		'Debian'                      => 'gdmflexiserver -ls',
		'Ubuntu'                      => 'dm-tool switch-to-greeter',
		default                       => '',
	}
	
	
	# attributes are in the messy order,
	# the packaged/distributed configuration file has
	# (for side-by-side comparison)
	class { 'xscreensaver':
		manage_xscreensaver_defaults  => false,
		# the distributed defaults:
		mode                          => 'random',
		timeout                       => {hours => 0, minutes => 10, seconds =>  0},
		cycle                         => {hours => 0, minutes => 10, seconds =>  0},
		lock_timeout                  => {hours => 0, minutes =>  0, seconds =>  0},
		passwd_timeout                => {hours => 0, minutes =>  0, seconds => 30},
		dpms_enabled                  => false,
		dpms_quickoff_enabled         => false,
		dpms_standby                  => {hours => 2, minutes =>  0, seconds =>  0},
		dpms_suspend                  => {hours => 2, minutes =>  0, seconds =>  0},
		dpms_off                      => {hours => 4, minutes =>  0, seconds =>  0},
		grab_desktop_images           => false,
		grab_video_frames             => false,
		choose_random_images          => false,
		image_directory               => '',
		nice                          => 10,
		memory_limit                  => 0,
		lock                          => false,
		verbose                       => false,
		timestamp                     => true,
		fade                          => true,
		unfade                        => false,
		fade_seconds                  => 3,
		fade_ticks                    => 20,
		splash                        => true,
		splash_duration               => {hours => 0, minutes => 0, seconds => 5},
		visual_id                     => 'default',
		capture_stderr                => true,
		ignore_uninstalled_programs   => false,
		auth_warning_slack            => 20,
		text_mode                     => 'url',
		text_literal                  => 'XScreenSaver',
		text_file                     => '',
		text_program                  => 'fortune',
		text_url                      => $_text_url,
		overlay_text_foreground       => [0xFF, 0xFF, 0x00],
		overlay_text_background       => [0x00, 0x00, 0x00],
		overlay_stderr                => true,
		font                          => '*-medium-r-*-140-*-m-*',
		sgi_saver_extension           => true,
		xidle_extension               => true,
		proc_interrupts               => true,
		xinput_extension_dev          => false,
		get_view_port_is_full_of_lies => false,
		demo_command                  => 'xscreensaver-demo',
		prefs_command                 => 'xscreensaver-demo -prefs',
		help_url                      => 'http://www.jwz.org/xscreensaver/man.html',
		load_url                      => 'x-www-browser \'%s\'',
		manual_command                => $_manual_command,
		date_format                   => '%Y-%m-%d %H:%M:%S',
		new_login_command             => $_new_login_command,
		install_colormap              => true,
		programs                      => {
				# /usr/lib/xscreensaver/maze originates from xscreensaver-data-extra
				'maze -root'                  => {},
				# /usr/lib/xscreensaver/superquadrics originates from xscreensaver-gl
				'superquadrics -root'         => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/attraction originates from xscreensaver-data-extra
				'attraction -root'            => {},
				# /usr/lib/xscreensaver/blitspin originates from xscreensaver-data-extra
				'blitspin -root'              => {},
				# /usr/lib/xscreensaver/greynetic originates from xscreensaver-data-extra
				'greynetic -root'             => {},
				# /usr/lib/xscreensaver/helix originates from xscreensaver-data-extra
				'helix -root'                 => {},
				# /usr/lib/xscreensaver/hopalong originates from xscreensaver-data-extra
				'hopalong -root'              => {},
				# /usr/lib/xscreensaver/imsmap originates from xscreensaver-data-extra
				'imsmap -root'                => {},
				# /usr/lib/xscreensaver/noseguy originates from xscreensaver-data-extra
				'noseguy -root'               => {inactive => true},
				# /usr/lib/xscreensaver/pyro originates from xscreensaver-data-extra
				'pyro -root'                  => {inactive => true},
				# /usr/lib/xscreensaver/qix originates from xscreensaver-data-extra
				'qix -root'                   => {},
				# /usr/lib/xscreensaver/rocks originates from xscreensaver-data-extra
				'rocks -root'                 => {inactive => true},
				# /usr/lib/xscreensaver/rorschach originates from xscreensaver-data-extra
				'rorschach -root'             => {},
				# /usr/lib/xscreensaver/decayscreen originates from xscreensaver-data-extra
				'decayscreen -root'           => {},
				# /usr/lib/xscreensaver/flame originates from xscreensaver-data-extra
				'flame -root'                 => {},
				# /usr/lib/xscreensaver/halo originates from xscreensaver-data-extra
				'halo -root'                  => {},
				# /usr/lib/xscreensaver/slidescreen originates from xscreensaver-data
				'slidescreen -root'           => {},
				# /usr/lib/xscreensaver/pedal originates from xscreensaver-data-extra
				'pedal -root'                 => {},
				# /usr/lib/xscreensaver/bouboule originates from xscreensaver-data-extra
				'bouboule -root'              => {},
				# /usr/lib/xscreensaver/braid originates from xscreensaver-data-extra
				'braid -root'                 => {inactive => true},
				# /usr/lib/xscreensaver/coral originates from xscreensaver-data-extra
				'coral -root'                 => {},
				# /usr/lib/xscreensaver/deco originates from xscreensaver-data
				'deco -root'                  => {},
				# /usr/lib/xscreensaver/drift originates from xscreensaver-data-extra
				'drift -root'                 => {},
				# /usr/lib/xscreensaver/fadeplot originates from xscreensaver-data-extra
				'fadeplot -root'              => {inactive => true},
				# /usr/lib/xscreensaver/galaxy originates from xscreensaver-data
				'galaxy -root'                => {},
				# /usr/lib/xscreensaver/goop originates from xscreensaver-data-extra
				'goop -root'                  => {},
				# /usr/lib/xscreensaver/grav originates from xscreensaver-data-extra
				'grav -root'                  => {},
				# /usr/lib/xscreensaver/ifs originates from xscreensaver-data-extra
				'ifs -root'                   => {},
				# /usr/lib/xscreensaver/unicode originates from unicode-screensaver
				'unicode -root'               => {},
				# /usr/lib/xscreensaver/jigsaw originates from xscreensaver-gl-extra
				'jigsaw -root'                => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/julia originates from xscreensaver-data-extra
				'julia -root'                 => {},
				# /usr/lib/xscreensaver/kaleidescope originates from xscreensaver-data-extra
				'kaleidescope -root'          => {inactive => true},
				# /usr/lib/xscreensaver/moebius originates from xscreensaver-gl
				'moebius -root'               => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/moire originates from xscreensaver-data-extra
				'moire -root'                 => {},
				# /usr/lib/xscreensaver/morph3d originates from xscreensaver-gl
				'morph3d -root'               => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/mountain originates from xscreensaver-data-extra
				'mountain -root'              => {},
				# /usr/lib/xscreensaver/munch originates from xscreensaver-data-extra
				'munch -root'                 => {},
				# /usr/lib/xscreensaver/penrose originates from xscreensaver-data
				'penrose -root'               => {},
				# /usr/lib/xscreensaver/pipes originates from xscreensaver-gl
				'pipes -root'                 => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/rd-bomb originates from xscreensaver-data-extra
				'rd-bomb -root'               => {},
				# /usr/lib/xscreensaver/rubik originates from xscreensaver-gl-extra
				'rubik -root'                 => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/sierpinski originates from xscreensaver-data-extra
				'sierpinski -root'            => {inactive => true},
				# /usr/lib/xscreensaver/slip originates from xscreensaver-data-extra
				'slip -root'                  => {},
				# /usr/lib/xscreensaver/sproingies originates from xscreensaver-gl-extra
				'sproingies -root'            => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/starfish originates from xscreensaver-data-extra
				'starfish -root'              => {},
				# /usr/lib/xscreensaver/strange originates from xscreensaver-data-extra
				'strange -root'               => {},
				# /usr/lib/xscreensaver/swirl originates from xscreensaver-data
				'swirl -root'                 => {},
				# /usr/lib/xscreensaver/triangle originates from xscreensaver-data-extra
				'triangle -root'              => {},
				# /usr/lib/xscreensaver/xjack originates from xscreensaver-data-extra
				'xjack -root'                 => {},
				# /usr/lib/xscreensaver/xlyap originates from xscreensaver-data
				'xlyap -root'                 => {},
				# /usr/lib/xscreensaver/atlantis originates from xscreensaver-gl-extra
				'atlantis -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/bsod originates from xscreensaver-screensaver-bsod
				'bsod -root'                  => {},
				# /usr/lib/xscreensaver/bubble3d originates from xscreensaver-gl
				'bubble3d -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/cage originates from xscreensaver-gl-extra
				'cage -root'                  => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/crystal originates from xscreensaver-data-extra
				'crystal -root'               => {inactive => true},
				# /usr/lib/xscreensaver/cynosure originates from xscreensaver-data-extra
				'cynosure -root'              => {},
				# /usr/lib/xscreensaver/discrete originates from xscreensaver-data-extra
				'discrete -root'              => {},
				# /usr/lib/xscreensaver/distort originates from xscreensaver-data
				'distort -root'               => {},
				# /usr/lib/xscreensaver/epicycle originates from xscreensaver-data-extra
				'epicycle -root'              => {},
				# /usr/lib/xscreensaver/flow originates from xscreensaver-data-extra
				'flow -root'                  => {},
				# /usr/lib/xscreensaver/glplanet originates from xscreensaver-gl-extra
				'glplanet -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/interference originates from xscreensaver-data-extra
				'interference -root'          => {},
				# /usr/lib/xscreensaver/kumppa originates from xscreensaver-data-extra
				'kumppa -root'                => {},
				# /usr/lib/xscreensaver/lament originates from xscreensaver-gl-extra
				'lament -root'                => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/moire2 originates from xscreensaver-data-extra
				'moire2 -root'                => {},
				# /usr/lib/xscreensaver/sonar originates from xscreensaver-gl
				'sonar -root'                 => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/stairs originates from xscreensaver-gl-extra
				'stairs -root'                => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/truchet originates from xscreensaver-data-extra
				'truchet -root'               => {},
				# /usr/lib/xscreensaver/vidwhacker originates from xscreensaver-data-extra
				'vidwhacker -root'            => {inactive => true},
				# /usr/lib/xscreensaver/blaster originates from xscreensaver-data-extra
				'blaster -root'               => {},
				# /usr/lib/xscreensaver/bumps originates from xscreensaver-data-extra
				'bumps -root'                 => {},
				# /usr/lib/xscreensaver/ccurve originates from xscreensaver-data-extra
				'ccurve -root'                => {},
				# /usr/lib/xscreensaver/compass originates from xscreensaver-data-extra
				'compass -root'               => {},
				# /usr/lib/xscreensaver/deluxe originates from xscreensaver-data-extra
				'deluxe -root'                => {},
				# /usr/lib/xscreensaver/demon originates from xscreensaver-data-extra
				'demon -root'                 => {inactive => true},
				# /usr/lib/xscreensaver/extrusion originates from xscreensaver-gl-extra
				'extrusion -root'             => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/loop originates from xscreensaver-data-extra
				'loop -root'                  => {inactive => true},
				# /usr/lib/xscreensaver/penetrate originates from xscreensaver-data-extra
				'penetrate -root'             => {},
				# /usr/lib/xscreensaver/petri originates from xscreensaver-data-extra
				'petri -root'                 => {},
				# /usr/lib/xscreensaver/phosphor originates from xscreensaver-data-extra
				'phosphor -root'              => {},
				# /usr/lib/xscreensaver/pulsar originates from xscreensaver-gl
				'pulsar -root'                => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/ripples originates from xscreensaver-data
				'ripples -root'               => {},
				# /usr/lib/xscreensaver/shadebobs originates from xscreensaver-data
				'shadebobs -root'             => {},
				# /usr/lib/xscreensaver/sierpinski3d originates from xscreensaver-gl
				'sierpinski3d -root'          => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/spotlight originates from xscreensaver-data-extra
				'spotlight -root'             => {},
				# /usr/lib/xscreensaver/squiral originates from xscreensaver-data-extra
				'squiral -root'               => {},
				# /usr/lib/xscreensaver/wander originates from xscreensaver-data-extra
				'wander -root'                => {},
				# /usr/lib/xscreensaver/webcollage originates from xscreensaver-screensaver-webcollage
				'webcollage -root'            => {inactive => true},
				# /usr/lib/xscreensaver/xflame originates from xscreensaver-data-extra
				'xflame -root'                => {},
				# /usr/lib/xscreensaver/xmatrix originates from xscreensaver-data-extra
				'xmatrix -root'               => {},
				# /usr/lib/xscreensaver/gflux originates from xscreensaver-gl
				'gflux -root'                 => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/nerverot originates from xscreensaver-data-extra
				'nerverot -root'              => {inactive => true},
				# /usr/lib/xscreensaver/xrayswarm originates from xscreensaver-data-extra
				'xrayswarm -root'             => {},
				# /usr/lib/xscreensaver/xspirograph originates from xscreensaver-data-extra
				'xspirograph -root'           => {},
				# /usr/lib/xscreensaver/circuit originates from xscreensaver-gl
				'circuit -root'               => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/dangerball originates from xscreensaver-gl-extra
				'dangerball -root'            => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/engine originates from xscreensaver-gl
				'engine -root'                => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/flipscreen3d originates from xscreensaver-gl
				'flipscreen3d -root'          => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/gltext originates from xscreensaver-gl
				'gltext -root'                => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/menger originates from xscreensaver-gl-extra
				'menger -root'                => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/molecule originates from xscreensaver-gl
				'molecule -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/rotzoomer originates from xscreensaver-data-extra
				'rotzoomer -root'             => {},
				# /usr/lib/xscreensaver/speedmine originates from xscreensaver-data-extra
				'speedmine -root'             => {},
				# /usr/lib/xscreensaver/starwars originates from xscreensaver-gl-extra
				'starwars -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/stonerview originates from xscreensaver-gl
				'stonerview -root'            => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/vermiculate originates from xscreensaver-data-extra
				'vermiculate -root'           => {},
				# /usr/lib/xscreensaver/whirlwindwarp originates from xscreensaver-data-extra
				'whirlwindwarp -root'         => {},
				# /usr/lib/xscreensaver/zoom originates from xscreensaver-data-extra
				'zoom -root'                  => {},
				# /usr/lib/xscreensaver/anemone originates from xscreensaver-data-extra
				'anemone -root'               => {},
				# /usr/lib/xscreensaver/apollonian originates from xscreensaver-data-extra
				'apollonian -root'            => {},
				# /usr/lib/xscreensaver/boxed originates from xscreensaver-gl-extra
				'boxed -root'                 => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/cubenetic originates from xscreensaver-gl-extra
				'cubenetic -root'             => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/endgame originates from xscreensaver-gl
				'endgame -root'               => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/euler2d originates from xscreensaver-data-extra
				'euler2d -root'               => {},
				# /usr/lib/xscreensaver/fluidballs originates from xscreensaver-data-extra
				'fluidballs -root'            => {},
				# /usr/lib/xscreensaver/flurry originates from xscreensaver-gl-extra
				'flurry -root'                => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/glblur originates from xscreensaver-gl
				'glblur -root'                => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/glsnake originates from xscreensaver-gl
				'glsnake -root'               => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/halftone originates from xscreensaver-data-extra
				'halftone -root'              => {},
				# /usr/lib/xscreensaver/juggler3d originates from xscreensaver-gl-extra
				'juggler3d -root'             => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/lavalite originates from xscreensaver-gl
				'lavalite -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/polyominoes originates from xscreensaver-data-extra
				'polyominoes -root'           => {inactive => true},
				# /usr/lib/xscreensaver/queens originates from xscreensaver-gl
				'queens -root'                => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/sballs originates from xscreensaver-gl-extra
				'sballs -root'                => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/spheremonics originates from xscreensaver-gl
				'spheremonics -root'          => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/thornbird originates from xscreensaver-data-extra
				'thornbird -root'             => {inactive => true},
				# /usr/lib/xscreensaver/twang originates from xscreensaver-data-extra
				'twang -root'                 => {},
				# /usr/lib/xscreensaver/antspotlight originates from xscreensaver-gl
				'antspotlight -root'          => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/apple2 originates from xscreensaver-data-extra
				'apple2 -root'                => {},
				# /usr/lib/xscreensaver/atunnel originates from xscreensaver-gl
				'atunnel -root'               => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/barcode originates from xscreensaver-data-extra
				'barcode -root'               => {},
				# /usr/lib/xscreensaver/blinkbox originates from xscreensaver-gl
				'blinkbox -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/blocktube originates from xscreensaver-gl-extra
				'blocktube -root'             => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/bouncingcow originates from xscreensaver-gl-extra
				'bouncingcow -root'           => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/cloudlife originates from xscreensaver-data-extra
				'cloudlife -root'             => {},
				# /usr/lib/xscreensaver/cubestorm originates from xscreensaver-gl
				'cubestorm -root'             => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/eruption originates from xscreensaver-data-extra
				'eruption -root'              => {},
				# /usr/lib/xscreensaver/flipflop originates from xscreensaver-gl
				'flipflop -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/flyingtoasters originates from xscreensaver-gl
				'flyingtoasters -root'        => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/fontglide originates from xscreensaver-data-extra
				'fontglide -root'             => {},
				# /usr/lib/xscreensaver/gleidoscope originates from xscreensaver-gl
				'gleidescope -root'           => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/glknots originates from xscreensaver-gl
				'glknots -root'               => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/glmatrix originates from xscreensaver-gl
				'glmatrix -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/glslideshow originates from xscreensaver-gl
				'glslideshow -root'           => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/hypertorus originates from xscreensaver-gl
				'hypertorus -root'            => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/jigglypuff originates from xscreensaver-gl
				'jigglypuff -root'            => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/metaballs originates from xscreensaver-data
				'metaballs -root'             => {},
				# /usr/lib/xscreensaver/mirrorblob originates from xscreensaver-gl
				'mirrorblob -root'            => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/piecewise originates from xscreensaver-data-extra
				'piecewise -root'             => {},
				# /usr/lib/xscreensaver/polytopes originates from xscreensaver-gl
				'polytopes -root'             => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/pong originates from xscreensaver-data-extra
				'pong -root'                  => {},
				# /usr/lib/xscreensaver/popsquares originates from xscreensaver-data
				'popsquares -root'            => {},
				# /usr/lib/xscreensaver/surfaces originates from xscreensaver-gl-extra
				'surfaces -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/xanalogtv originates from xscreensaver-data-extra
				'xanalogtv -root'             => {},
				# /usr/lib/xscreensaver/abstractile originates from xscreensaver-data
				'abstractile -root'           => {inactive => true},
				# /usr/lib/xscreensaver/anemotaxis originates from xscreensaver-data-extra
				'anemotaxis -root'            => {},
				# /usr/lib/xscreensaver/antinspect originates from xscreensaver-gl
				'antinspect -root'            => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/fireworkx originates from xscreensaver-data-extra
				'fireworkx -root'             => {},
				# /usr/lib/xscreensaver/fuzzyflakes originates from xscreensaver-data
				'fuzzyflakes -root'           => {},
				# /usr/lib/xscreensaver/interaggregate originates from xscreensaver-data-extra
				'interaggregate -root'        => {},
				# /usr/lib/xscreensaver/intermomentary originates from xscreensaver-data-extra
				'intermomentary -root'        => {},
				# /usr/lib/xscreensaver/memscroller originates from xscreensaver-data-extra
				'memscroller -root'           => {},
				# /usr/lib/xscreensaver/noof originates from xscreensaver-gl-extra
				'noof -root'                  => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/pacman originates from xscreensaver-data-extra
				'pacman -root'                => {},
				# /usr/lib/xscreensaver/pinion originates from xscreensaver-gl-extra
				'pinion -root'                => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/polyhedra originates from xscreensaver-gl
				'polyhedra -root'             => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/providence originates from xscreensaver-gl-extra
				'providence -root'            => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/substrate originates from xscreensaver-data-extra
				'substrate -root'             => {},
				# /usr/lib/xscreensaver/wormhole originates from xscreensaver-data-extra
				'wormhole -root'              => {},
				# /usr/lib/xscreensaver/antmaze originates from xscreensaver-gl-extra
				'antmaze -root'               => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/boing originates from xscreensaver-gl-extra
				'boing -root'                 => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/extra originates from xscreensaver-data-extra
				'boxfit -root'                => {},
				# /usr/lib/xscreensaver/carousel originates from xscreensaver-gl-extra
				'carousel -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/celtic originates from xscreensaver-data-extra
				'celtic -root'                => {},
				# /usr/lib/xscreensaver/crackberg originates from xscreensaver-gl-extra
				'crackberg -root'             => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/cube21 originates from xscreensaver-gl-extra
				'cube21 -root'                => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/fiberlamp originates from xscreensaver-data
				'fiberlamp -root'             => {},
				# /usr/lib/xscreensaver/fliptext originates from xscreensaver-gl-extra
				'fliptext -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/glhanoi originates from xscreensaver-gl-extra
				'glhanoi -root'               => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/tangram originates from xscreensaver-gl-extra
				'tangram -root'               => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/timetunnel originates from xscreensaver-gl-extra
				'timetunnel -root'            => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/glschool originates from xscreensaver-gl
				'glschool -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/topblock originates from xscreensaver-gl
				'topblock -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/cubicgrid originates from xscreensaver-gl-extra
				'cubicgrid -root'             => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/cwaves originates from xscreensaver-data
				'cwaves -root'                => {},
				# /usr/lib/xscreensaver/gears originates from xscreensaver-gl
				'gears -root'                 => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/glcells originates from xscreensaver-gl
				'glcells -root'               => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/lockward originates from xscreensaver-gl
				'lockward -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/m6502 originates from xscreensaver-data
				'm6502 -root'                 => {},
				# /usr/lib/xscreensaver/moebiusgears originates from xscreensaver-gl
				'moebiusgears -root'          => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/voronoi originates from xscreensaver-gl
				'voronoi -root'               => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/hypnowheel originates from xscreensaver-gl-extra
				'hypnowheel -root'            => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/klein originates from xscreensaver-gl-extra
				'klein -root'                 => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/lcdscrub originates from xscreensaver-data-extra
				'lcdscrub -root'              => {inactive => true},
				# /usr/lib/xscreensaver/photopile originates from xscreensaver-gl-extra
				'photopile -root'             => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/skytentacles originates from xscreensaver-gl-extra
				'skytentacles -root'          => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/rubikblocks originates from xscreensaver-gl-extra
				'rubikblocks -root'           => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/companioncube originates from xscreensaver-gl-extra
				'companioncube -root'         => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/hilbert originates from xscreensaver-gl-extra
				'hilbert -root'               => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/tronbit originates from xscreensaver-gl-extra
				'tronbit -root'               => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/geodesic originates from xscreensaver-gl
				'geodesic -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/hexadrop originates from xscreensaver-data
				'hexadrop -root'              => {},
				# /usr/lib/xscreensaver/kaleidocycle originates from xscreensaver-gl
				'kaleidocycle -root'          => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/quasicrystal originates from xscreensaver-gl
				'quasicrystal -root'          => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/unknownpleasures originates from xscreensaver-gl-extra
				'unknownpleasures -root'      => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/binaryring originates from xscreensaver-data
				'binaryring -root'            => {},
				# /usr/lib/xscreensaver/cityflow originates from xscreensaver-gl
				'cityflow -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/geodesicgears originates from xscreensaver-gl
				'geodesicgears -root'         => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/projectiveplane originates from xscreensaver-gl
				'projectiveplane -root'       => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/romanboy originates from xscreensaver-gl
				'romanboy -root'              => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/tessellimage originates from xscreensaver-data
				'tessellimage -root'          => {},
				# /usr/lib/xscreensaver/winduprobot originates from xscreensaver-gl
				'winduprobot -root'           => {inactive => true, visuals => 'GL'},
				# /usr/lib/xscreensaver/splitflap originates from xscreensaver-gl
				'splitflap -root'             => {inactive => true, visuals => 'GL'},
				# XXX XXX XXX XXX XXX testx11 originates from XXX XXX XXX XXX XXX
				'testx11 -root'               => {},
			},
		pointer_poll_time             => {hours => 0, minutes => 0, seconds => 5},
		pointer_hysteresis            => 10,
		initial_delay                 => {hours => 0, minutes => 0, seconds => 0},
		window_creation_timeout       => {hours => 0, minutes => 0, seconds => 30},
		bourne_shell                  => '/bin/sh',
		# Resources for the password and splash-screen dialog boxes of the "xscreensaver" daemon.
		dialog_heading_font           => '*-helvetica-bold-r-*-*-*-180-*-*-*-iso8859-1',
		dialog_body_font              => '*-helvetica-bold-r-*-*-*-140-*-*-*-iso8859-1',
		dialog_label_font             => '*-helvetica-bold-r-*-*-*-140-*-*-*-iso8859-1',
		dialog_uname_font             => '*-helvetica-bold-r-*-*-*-120-*-*-*-iso8859-1',
		dialog_button_font            => '*-helvetica-bold-r-*-*-*-140-*-*-*-iso8859-1',
		dialog_date_font              => '*-helvetica-medium-r-*-*-*-80-*-*-*-iso8859-1',
		# Helvetica asterisks look terrible.
		#passwd_passwd_font            => '*-helvetica-medium-r-*-*-*-140-*-*-*-iso8859-1'
		passwd_passwd_font            => '*-courier-medium-r-*-*-*-140-*-*-*-iso8859-1',
		dialog_foreground             => [0x00, 0x00, 0x00],
		dialog_background             => [0xE6, 0xE6, 0xE6],
		dialog_button_foreground      => [0x00, 0x00, 0x00],
		dialog_button_background      => [0xF5, 0xF5, 0xF5],
		#dialog_button_point_bg        => [0xEA, 0xEA, 0xEA],
		#dialog_button_click_bg        => [0xC3, 0xC3, 0xC3],
		dialog_text_foreground        => [0x00, 0x00, 0x00],
		dialog_text_background        => [0xFF, 0xFF, 0xFF],
		passwd_thermometer_foreground => [0x44, 0x64, 0xAC],
		passwd_thermometer_background => [0xFF, 0xFF, 0xFF],
		dialog_top_shadow_color       => [0xFF, 0xFF, 0xFF],
		dialog_bottom_shadow_color    => [0xCE, 0xCE, 0xCE],
		dialog_logo_width             => 210,
		dialog_logo_height            => 210,
		dialog_internal_border_width  => 24,
		dialog_border_width           => 1,
		dialog_shadow_thickness       => 2,
		passwd_heading_label          => 'XScreenSaver %s',
		passwd_body_label             => 'Please enter your password.',
		passwd_unlock_label           => 'OK',
		passwd_login_label            => 'New Login',
		passwd_user_label             => 'Username:',
		passwd_passwd_label           => 'Password:',
		passwd_thermometer_width      => 8,
		passwd_asterisks              => true,
		passwd_uname                  => true,
		splash_heading_label          => 'XScreenSaver %s',
		splash_body_label             => 'Copyright \251 1991-2014 by',
		splash_body2_label            => 'Jamie Zawinski <jwz@jwz.org>',
		splash_demo_label             => 'Settings',
		splash_help_label             => 'Help',
		hacks__name                   => {
				'antinspect'                  => 'AntInspect',
				'antmaze'                     => 'AntMaze',
				'antspotlight'                => 'AntSpotlight',
				'binaryring'                  => 'BinaryRing',
				'blinkbox'                    => 'BlinkBox',
				'blitspin'                    => 'BlitSpin',
				'blocktube'                   => 'BlockTube',
				'bouncingcow'                 => 'BouncingCow',
				'boxfit'                      => 'BoxFit',
				'bsod'                        => 'BSOD',
				'bubble3d'                    => 'Bubble3D',
				'ccurve'                      => 'CCurve',
				'cloudlife'                   => 'CloudLife',
				'companioncube'               => 'CompanionCube',
				'cubestorm'                   => 'CubeStorm',
				'cubicgrid'                   => 'CubicGrid',
				'cwaves'                      => 'CWaves',
				'dangerball'                  => 'DangerBall',
				'decayscreen'                 => 'DecayScreen',
				'dnalogo'                     => 'DNA Logo',
				'euler2d'                     => 'Euler2D',
				'fadeplot'                    => 'FadePlot',
				'flipflop'                    => 'FlipFlop',
				'flipscreen3d'                => 'FlipScreen3D',
				'fliptext'                    => 'FlipText',
				'fluidballs'                  => 'FluidBalls',
				'flyingtoasters'              => 'FlyingToasters',
				'fontglide'                   => 'FontGlide',
				'fuzzyflakes'                 => 'FuzzyFlakes',
				'geodesicgears'               => 'GeodesicGears',
				'gflux'                       => 'GFlux',
				'gleidescope'                 => 'Gleidescope',
				'glforestfire'                => 'GLForestFire',
				'hyperball'                   => 'HyperBall',
				'hypercube'                   => 'HyperCube',
				'ifs'                         => 'IFS',
				'imsmap'                      => 'IMSMap',
				'jigglypuff'                  => 'JigglyPuff',
				'juggler3d'                   => 'Juggler3D',
				'lcdscrub'                    => 'LCDscrub',
				'lmorph'                      => 'LMorph',
				'm6502'                       => 'm6502',
				'memscroller'                 => 'MemScroller',
				'metaballs'                   => 'MetaBalls',
				'mirrorblob'                  => 'MirrorBlob',
				'moebiusgears'                => 'MoebiusGears',
				'morph3d'                     => 'Morph3D',
				'nerverot'                    => 'NerveRot',
				'noseguy'                     => 'NoseGuy',
				'popsquares'                  => 'PopSquares',
				'projectiveplane'             => 'ProjectivePlane',
				'quasicrystal'                => 'QuasiCrystal',
				'rd-bomb'                     => 'RDbomb',
				'rdbomb'                      => 'RDbomb',
				'romanboy'                    => 'RomanBoy',
				'rotzoomer'                   => 'RotZoomer',
				'rubikblocks'                 => 'RubikBlocks',
				'sballs'                      => 'SBalls',
				'shadebobs'                   => 'ShadeBobs',
				'sierpinski3d'                => 'Sierpinski3D',
				'skytentacles'                => 'SkyTentacles',
				'slidescreen'                 => 'SlideScreen',
				'speedmine'                   => 'SpeedMine',
				'splitflap'                   => 'SplitFlap',
				'starwars'                    => 'StarWars',
				'stonerview'                  => 'StonerView',
				't3d'                         => 'T3D',
				'testx11'                     => 'TestX11',
				'timetunnel'                  => 'TimeTunnel',
				'topblock'                    => 'TopBlock',
				'tronbit'                     => 'TronBit',
				'unknownpleasures'            => 'UnknownPleasures',
				'vidwhacker'                  => 'VidWhacker',
				'webcollage'                  => 'WebCollage',
				'whirlwindwarp'               => 'WhirlWindWarp',
				'winduprobot'                 => 'WindupRobot',
				'xanalogtv'                   => 'XAnalogTV',
				'xrayswarm'                   => 'XRaySwarm',
			},
		# obsolete, but still used by xscreensaver-demo-Xm.
		hacks_doc_is_installed        => true,
	}
}
# EOF
