# name: configure xscreensaver
# desc: configuration manifest for xscreensaver module
# auth: Kai Burghardt <kburgha at gwdg.de>
#  vim: set tw=140 ts=4 noet bs=eol,start,indent fdm=marker:

class xscreensaver::config {
	# V A R I A B L E   I N I T
	
	# lint:ignore:only_variable_string
	# undef renders as empty string
	$_pending_removal = ("${xscreensaver::xscreensaver_package_version}" =~ /^(absent|purged)$/)
	# lint:endignore
	
	if ($xscreensaver::xscreensaver_defaults_profile == default) {
		# pick the default profile name
		# by looking which package installations were requested
		if ($xscreensaver::packages_have in $xscreensaver::xscreensaver_gl_packages) or
		($xscreensaver::xscreensaver_package_name in $xscreensaver::xscreensaver_gl_packages) {
			$_default_profile              = 'gl'
		} else {
			$_default_profile              = 'nogl'
		}
	} else {
		$_default_profile              = $xscreensaver::xscreensaver_defaults_profile
	}
	
	$_defaults_path                = @("EOT"/L)
			${xscreensaver::xscreensaver_defaults_dir}\
			${xscreensaver::xscreensaver_defaults_base}
			|-EOT
	# filename (without directory)
	$_profile_path_base            = @("EOT"/L)
			${xscreensaver::xscreensaver_defaults_base}-${_default_profile}
			|-EOT
	# whole path to the file
	$_profile_path                 = @("EOT"/L)
			${xscreensaver::xscreensaver_defaults_dir}\
			${_profile_path_base}
			|-EOT
	# used as resource title
	$_profile_resource             = "xscreensaver_defaults_${_default_profile}"
	
	$_autostart_link               = $xscreensaver::do_autostart ? {
		true                          => link,
		default                       => absent,
	}
	$_autostart_file               = $xscreensaver::do_autostart ? {
		true                          => file,
		default                       => absent,
	}
	
	
	# C O N F I G U R A T I O N   F I L E S
	
	if ($xscreensaver::manage_xscreensaver_defaults and ! $_pending_removal) {
		file { $_profile_resource:
			path                          => $_profile_path,
			ensure                        => file,
			mode                          => '0644',
			owner                         => 'root',
			group                         => 'root',
			content                       => template($xscreensaver::xscreensaver_defaults_erb),
		}
		
		file { 'xscreensaver_defaults_profile':
			path                          => $_defaults_path,
			ensure                        => link,
			mode                          => '0777',
			owner                         => 'root',
			group                         => 'root',
			target                        => $_profile_path_base,
		}
	}
	
	# A U T O S T A R T
	if ($xscreensaver::manage_xdg_autostart and ! $_pending_removal) {
		if ($xscreensaver::xdg_autostart_file_type == 'symlink') {
			file { 'xdg_autostart_xcreensaver_daemon':
				path                          => $xscreensaver::xdg_autostart_path,
				ensure                        => $_autostart_link,
				mode                          => '0777',
				owner                         => 'root',
				group                         => 'root',
				target                        => $xscreensaver::xdg_autostart_target,
			}
		}
		
		if ($xscreensaver::xdg_autostart_file_type == 'regularfile') {
			file { 'xdg_autostart_xcreensaver_daemon':
				path                          => $xscreensaver::xdg_autostart_path,
				ensure                        => $_autostart_file,
				mode                          => '0644',
				owner                         => 'root',
				group                         => 'root',
				content                       => template($xscreensaver::xdg_autostart_erb),
			}
		}
	}
	
	if ($xscreensaver::manage_wrapper_script and ! $_pending_removal) {
		file { 'xscreensaver_wrapper':
			path                          => $xscreensaver::autostart_wrapper_path,
			ensure                        => file,
			mode                          => '0755',
			owner                         => 'root',
			group                         => 'root',
			content                       => template($xscreensaver::autostart_wrapper_erb),
		}
	}
}
# EOF
