# name: X screensaver init puppet
# desc: init manifest for xscreensaver module
# auth: Kai Burghardt <kburgha at gwdg.de>
#  vim: set tw=140 ts=4 noet bs=eol,start,indent fdm=marker fdl=0:

class xscreensaver (
	# P A C K A G E
	Pattern[/^.+$/]          $xscreensaver_package_name     = $xscreensaver::params::xscreensaver_package_name,
	Optional[Pattern[/^.+$/]]
	                         $xscreensaver_package_version  = undef,
	Optional[Array[Pattern[/^.+$/], 1]]
	                         $packages_have                 = undef,
	Optional[Array[Pattern[/^.+$/], 1]]
	                         $packages_abolish              = $xscreensaver::params::xscreensaver_gl_packages,
	Boolean                  $latest_instead_of_present     = false,
	Boolean                  $purge_instead_of_remove       = true,
	# C O N F I G U R A T I O N
	# app-defaults
	Boolean                  $manage_xscreensaver_defaults  = false,
	String                   $xscreensaver_defaults_dir     = $xscreensaver::params::xscreensaver_defaults_dir,
	String                   $xscreensaver_defaults_base    = $xscreensaver::params::xscreensaver_defaults_base,
	String                   $xscreensaver_defaults_erb     = $xscreensaver::params::xscreensaver_defaults_erb,
	Variant[Pattern[/^[a-z]+$/], Default]
	                         $xscreensaver_defaults_profile = default,
	# xdg-autostart
	Boolean                  $manage_xdg_autostart          = false,
	Boolean                  $do_autostart                  = true,
	Boolean                  $manage_wrapper_script         = false,
	Enum['symlink', 'regularfile']
	                         $xdg_autostart_file_type       = 'symlink',
	String                   $xdg_autostart_path            = $xscreensaver::params::xdg_autostart_path,
	String                   $xdg_autostart_target          = $xscreensaver::params::xdg_autostart_target,
	String                   $xdg_autostart_erb             = $xscreensaver::params::xdg_autostart_erb,
	String                   $autostart_wrapper_path        = $xscreensaver::params::autostart_wrapper_path,
	String                   $autostart_wrapper_erb         = $xscreensaver::params::autostart_wrapper_erb,
	String                   $xdg_autostart_exec_args       = $xscreensaver::params::xdg_autostart_exec_args,
	# A P P L I C A T I O N   D E F A U L T S
	# splash
	Optional[Boolean]        $splash                        = undef,
	Optional[Pattern[/^[^\n]*$/]]
	                         $splash_heading_label          = undef,
	Optional[Pattern[/^[^\n]*$/]]
	                         $splash_body_label             = undef,
	Optional[Pattern[/^[^\n]*$/]]
	                         $splash_body2_label            = undef,
	Optional[Pattern[/^[^\n]*$/]]
	                         $splash_demo_label             = undef,
	Optional[Pattern[/^(.|\\\n)*$/]]
	                         $demo_command                  = undef,
	Optional[Pattern[/^(.|\\\n)*$/]]
	                         $prefs_command                 = undef,
	Optional[Pattern[/^[^\n]*$/]]
	                         $splash_help_label             = undef,
	Optional[Struct[{
			hours                         => Optional[Integer[0, 9]],
			minutes                       => Optional[Integer[0, 59]],
			seconds                       => Integer[0, 59],
		}]] $splash_duration = undef,
	# idleness detection
	Optional[Struct[{
			hours                         => Integer[0, 9],
			minutes                       => Integer[0, 59],
			seconds                       => Integer[0, 59],
		}]] $timeout = undef,
	Optional[Struct[{
			hours                         => Optional[Integer[0, 9]],
			minutes                       => Optional[Integer[0, 59]],
			seconds                       => Integer[0, 59],
		}]] $pointer_poll_time = undef,
	Optional[Integer]        $pointer_hysteresis            = undef,
	Optional[Boolean]        $sgi_saver_extension           = undef,
	Optional[Boolean]        $xidle_extension               = undef,
	Optional[Boolean]        $proc_interrupts               = undef,
	Optional[Boolean]        $xinput_extension_dev          = undef,
	# start
	Optional[Boolean]        $fade                          = undef,
	Optional[Integer[0, 59]] $fade_seconds                  = undef,
	Optional[Integer[0]]     $fade_ticks                    = undef,
	# screensaving
	Optional[Enum['random', 'random-same', 'one', 'blank', 'off']]
	                         $mode                          = undef,
	Optional[Variant[
			Enum['best', 'mono', 'gray', 'color', 'GL', 'default'],
			Enum['StaticGray', 'StaticColor', 'TrueColor', 'GrayScale', 'PseudoColor', 'DirectColor'],
			Integer[0]
		]] $visual_id = undef,
	Optional[Struct[{
			hours                         => Integer[0, 9],
			minutes                       => Integer[0, 59],
			seconds                       => Integer[0, 59],
		}]] $cycle = undef,
	Optional[Boolean]        $ignore_uninstalled_programs   = undef,
	Optional[Boolean]        $get_view_port_is_full_of_lies = undef,
	Optional[Boolean]        $install_colormap              = undef,
	Optional[Enum['date', 'literal', 'file', 'program', 'url']]
	                         $text_mode                     = undef,
	Optional[Pattern[/^[^\n]*/]]
	                         $text_literal                  = undef,
	Optional[Pattern[/^[^[:blank:]\n]*$/]]
	                         $text_file                     = undef,
	Optional[Pattern[/^(.|\\\n)*$/]]
	                         $text_program                  = undef,
	Optional[Pattern[/^[^[:blank:]\n]*$/]]
	                         $text_url                      = undef,
	Optional[Boolean]        $grab_desktop_images           = undef,
	Optional[Boolean]        $grab_video_frames             = undef,
	Optional[Boolean]        $choose_random_images          = undef,
	Optional[Pattern[/^[^[:blank:]\n]*$/]]
	                         $image_directory               = undef,
	Optional[Integer[-20, 19]]
	                         $nice                          = undef,
	Optional[Integer[0]]     $memory_limit                  = undef,
	Optional[Boolean]        $dpms_enabled                  = undef,
	Optional[Boolean]        $dpms_quickoff_enabled         = undef,
	Optional[Struct[{
			hours                         => Integer[0, 9],
			minutes                       => Integer[0, 59],
			seconds                       => Integer[0, 59],
		}]] $dpms_standby = undef,
	Optional[Struct[{
			hours                         => Integer[0, 9],
			minutes                       => Integer[0, 59],
			seconds                       => Integer[0, 59],
		}]] $dpms_suspend = undef,
	Optional[Struct[{
			hours                         => Integer[0, 9],
			minutes                       => Integer[0, 59],
			seconds                       => Integer[0, 59],
		}]] $dpms_off = undef,
	Optional[Boolean]        $lock                          = undef,
	Optional[Struct[{
			hours                         => Integer[0, 9],
			minutes                       => Integer[0, 59],
			seconds                       => Integer[0, 59],
		}]] $lock_timeout = undef,
	# back to work
	Optional[Boolean]        $unfade                        = undef,
	Optional[Pattern[/^[^\n]*$/]]
	                         $passwd_heading_label          = undef,
	Optional[Pattern[/^[^\n]*$/]]
	                         $passwd_body_label             = undef,
	Optional[Boolean]        $passwd_uname                  = undef,
	Optional[Pattern[/^[^\n]*$/]]
	                         $passwd_user_label             = undef,
	Optional[Pattern[/^[^\n]*$/]]
	                         $passwd_passwd_label           = undef,
	Optional[Array[Integer[0x00, 0xFF], 3, 3]]
	                         $passwd_thermometer_background = undef,
	Optional[Array[Integer[0x00, 0xFF], 3, 3]]
	                         $passwd_thermometer_foreground = undef,
	Optional[Integer[0]]     $passwd_thermometer_width      = undef,
	Optional[Struct[{
			hours                         => Integer[0, 9],
			minutes                       => Integer[0, 59],
			seconds                       => Integer[0, 59],
		}]] $passwd_timeout = undef,
	Optional[Pattern[/^[^[:blank:]\n]*$/]]
	                         $passwd_passwd_font            = undef,
	Optional[Boolean]        $passwd_asterisks              = undef,
	Optional[Pattern[/^[^\n]*$/]]
	                         $passwd_unlock_label           = undef,
	Optional[Pattern[/^[^\n]*$/]]
	                         $passwd_login_label            = undef,
	Optional[Pattern[/^(.|\\\n)*$/]]
	                         $new_login_command             = undef,
	Optional[Integer]        $auth_warning_slack            = undef,
	# user interface
	Optional[Pattern[/^(.|\\\n)*$/]]
	                         $help_url                      = undef,
	Optional[Pattern[/^(.|\\\n)*$/]]
	                         $load_url                      = undef,
	Optional[Pattern[/^(.|\\\n)*$/]]
	                         $manual_command                = undef,
	Optional[Boolean]        $hacks_doc_is_installed        = undef,
	Optional[Boolean]        $verbose                       = undef,
	Optional[Boolean]        $timestamp                     = undef,
	Optional[Array[Integer[0x00, 0xFF], 3, 3]]
	                         $dialog_background             = undef,
	Optional[Array[Integer[0x00, 0xFF], 3, 3]]
	                         $dialog_foreground             = undef,
	Optional[Integer[0]]     $dialog_internal_border_width  = undef,
	Optional[Integer[0]]     $dialog_border_width           = undef,
	Optional[Integer[0]]     $dialog_shadow_thickness       = undef,
	Optional[Array[Integer[0x00, 0xFF], 3, 3]]
	                         $dialog_top_shadow_color       = undef,
	Optional[Array[Integer[0x00, 0xFF], 3, 3]]
	                         $dialog_bottom_shadow_color    = undef,
	Optional[Integer[0]]     $dialog_logo_width             = undef,
	Optional[Integer[0]]     $dialog_logo_height            = undef,
	Optional[Array[Integer[0x00, 0xFF], 3, 3]]
	                         $dialog_text_background        = undef,
	Optional[Array[Integer[0x00, 0xFF], 3, 3]]
	                         $dialog_text_foreground        = undef,
	Optional[Pattern[/^[^[:blank:]\n]*$/]]
	                         $dialog_body_font              = undef,
	Optional[Pattern[/^[^[:blank:]\n]*$/]]
	                         $dialog_heading_font           = undef,
	Optional[Pattern[/^[^[:blank:]\n]*$/]]
	                         $dialog_label_font             = undef,
	Optional[Pattern[/^[^[:blank:]\n]*$/]]
	                         $dialog_uname_font             = undef,
	Optional[Pattern[/^[^[:blank:]\n]*$/]]
	                         $dialog_date_font              = undef,
	Optional[Pattern[/^[^[:blank:]\n]*$/]]
	                         $dialog_button_font            = undef,
	Optional[Array[Integer[0x00, 0xFF], 3, 3]]
	                         $dialog_button_background      = undef,
	Optional[Array[Integer[0x00, 0xFF], 3, 3]]
	                         $dialog_button_foreground      = undef,
	Optional[Array[Integer[0x00, 0xFF], 3, 3]]
	                         $dialog_button_point_bg        = undef,
	Optional[Array[Integer[0x00, 0xFF], 3, 3]]
	                         $dialog_button_click_bg        = undef,
	# miscellaneous
	Optional[Boolean]        $capture_stderr                = undef,
	Optional[Boolean]        $overlay_stderr                = undef,
	Optional[Pattern[/^[^[:blank:]\n]*$/]]
	                         $font                          = undef,
	Optional[Array[Integer[0x00, 0xFF], 3, 3]]
	                         $overlay_text_background       = undef,
	Optional[Array[Integer[0x00, 0xFF], 3, 3]]
	                         $overlay_text_foreground       = undef,
	Optional[Pattern[/^(.|\\\n)*$/]]
	                         $date_format                   = undef,
	Optional[Struct[{
			hours                         => Optional[Integer[0, 9]],
			minutes                       => Optional[Integer[0, 59]],
			seconds                       => Integer[0, 59],
		}]] $initial_delay     = undef,
	Optional[Struct[{
			hours                         => Optional[Integer[0, 9]],
			minutes                       => Optional[Integer[0, 59]],
			seconds                       => Integer[0, 59],
		}]] $window_creation_timeout = undef,
	Optional[Pattern[/^[^\n]*$/]]
	                         $bourne_shell                  = undef,
	# programs
	Optional[Hash[Pattern[/^[^&;\n]+$/], Struct[{
			inactive                      => Optional[Boolean],
			visuals                       => Optional[Enum[
					'mono',
					'color',
					'PseudoColor',
					'TrueColor',
					'GL'
				]],
		}], 1]] $programs = undef,
	# hacks
	# parameter 'hacks__name' entry 'foo' expects a match for Pattern[/^[^\n]*$/], got String
	#Optional[Hash[Pattern[/^[a-z0-9\-_]+$/], Pattern[/^[^\n]*$/], 1]]
	# parameter 'hacks__name' entry 'bar' expects a match for Pattern[/^.*$/], got String
	#Optional[Hash[Pattern[/^[a-z0-9\-_]+$/], Pattern[/^.*$/], 1]]
	Optional[Hash[Pattern[/^[a-z0-9\-_]+$/], String, 1]]
	                         $hacks__name                   = undef,
) inherits xscreensaver::params {
	Class['xscreensaver::install'] -> Class['xscreensaver::config']
	contain 'xscreensaver::install'
	contain 'xscreensaver::config'
}
# EOF
